% INIT_SIM simulates parametric resonance for a 
%  container ship in head seas, and plots the roll angle.
%
% See also: COMPUTE_TAU, COMPUTE_X_DOT, THE_SYSTEM.MDL

clear all; close all; clc;

% Conversion Parameters
D2R = pi/180; % deg to rad  
R2D = 180/pi; % rad to deg

% Ship Model Parameters
const.I_x    = 1.4014*(10^10); const.A_44    = 2.17*(10^9);
const.B_44   = -3.20*(10^8);   const.nabla   = 76468;
const.GM_m   = 1.91;           const.GM_a    = 0.84;
const.w_0    = 0.4764;         const.omega_0 = 0.4784;
const.K_phi3 = -2.974*(10^9);  const.lambda  = 0.1018;
const.sigma  = 1.2871;         const.m       = 7.6654*(10^7);      
const.A_11   = 7.746*(10^6);   const.rho     = 1025;
const.S      = 6600;           const.g       = 9.81; 
const.L_pp   = 281;            const.v       = 1.519*(10^-6);
const.k      = 0.1;            const.u       = 7;
const.k_p    = -10;            const.u_c     = 7;
const.tau    = 2.6805e+005;    u_c           = 7; 
const.R_n    = const.u*const.L_pp/const.v;
const.B_11   = 0.5*const.rho*const.S*(1+const.k)...
               *0.075/((log(const.R_n)/log(10)-2)^2);
const.Ix_A44 = const.I_x + const.A_44;
const.m_A11  = const.m + const.A_11;
const.C_44   = const.rho*const.g*const.nabla;
const.K_w    = 2*const.lambda*const.omega_0*const.sigma;
x_initial    = [0.05*D2R,0,7.5,const.w_0,1,0,0,0];

%% Start Simulation
Tstop    = 1000; sim('The_System',Tstop);

%% Plot
FontSize = 11*1.5;
xaxis    = x.time(1:10:10001); 
data1    = x.signals.values(1:10:10001)*R2D;

hfig     = figure(1); clf;
set(gcf,'units','centimeters','pos',[0 0 20 12])
set(gcf,'Color',[1 1 1]); % Sets figure background
set(gca,'Color',[1 1 1]); % Sets axes background
set(gcf,'Renderer','painters'); 

hLine1   = line(xaxis, data1);
set(hLine1,'LineWidth',1.4,'Color',[0 0 0]);

% Title, and names for the axes
hTitle   = title ('Plot of Roll Angle, Simulink Model');
hXLabel  = xlabel('Time [sec]');
hYLabel  = ylabel('Roll angle [deg]');

set(gca,'FontName','Helcetica');
set([hTitle,hXLabel,hYLabel],'FontName','Helcetica');
set([hXLabel,hYLabel],'FontSize',FontSize);
set(hTitle,'FontSize',FontSize,'FontWeight','bold');
set(gca,'TickDir','out','LineWidth',1.0);