% FFT_EncFreq
%  calculates the Fast Fourier Transform of estimated 
%  state 5, calculates and displays the value of the 
%  encounter frequency, and plots a single-sided 
%  amplitude spectrum.

% Run one filter (comment out the other one)
UKF;
% EKF;

%% Fast Fourier Transform
g = simdata(:,14);      % estimate of state 5
NFFT = 2^nextpow2(N+1); % next power of 2 from length of g
G = fft(g,NFFT)/(N+1);  % discrete Fourier transform of g
freq = (1/(2*h))*linspace(0,1,NFFT/2+1); % x-axis

%% Calculate the wave encounter frequency from the FFT
Enc_Freq = ((find(abs(G) == max(abs(G)),1)-1)/...
           (NFFT/2+1))*(1/(2*h))*2*pi; 
       
%% Display the value of the calculated encounter freq.       
disp(['Wave Encounter Frequency = ' ...
    num2str(Enc_Freq) '[rad/sec]']); 

%% Plot Single-Sided Ampl. Spectrum of Enc. Freq.
close all; figure;
set(gcf,'units','centimeters','pos',[0 0 20 12])
set(gcf,'Color',[1 1 1]); % sets figure background
hLine1 = line(freq,2*abs(G(1:NFFT/2+1)));
set(hLine1,'Color',[0.35 0.35 0.35]); 

% Title, and names on axes
hTitle  = title ('Single-Sided Amplitude Spectrum of w_e');
hXLabel = xlabel('Frequency [Hz]'); hYLabel = ylabel('|w_e|');

set(gca, 'FontName', 'Helvetica');
set([hTitle, hXLabel, hYLabel], 'FontName', 'Helvetica');
set([hXLabel, hYLabel], 'FontSize', 16.5);
set( hTitle, 'FontSize', 16.5, 'FontWeight', 'bold');