function [ x_dot ] = compute_f( X,U,const )
% COMPUTE_F returns the f = x_dot for a container vessel
%  during parametric resonance, for a given time instant.
%
% [ x_dot ] = compute_f( X,U,const )
%         X - system state [X(1) X(2) ... X(7) X(8)]' 
            % X(1) = phi
            % X(2) = (phi_dot)
            % X(3) = u
            % X(4) = w_0
            % X(5) = cos(integral[w_e(t)dt])
            % X(6) = d/dt cos(integral[w_e(t)dt])
            % X(7) = h_{wave}(s) 
            % X(8) = h_{wave}(s)_dot
%         U - system input u 
%     const - a struct with constant values 

  x_dot(1,1) = X(2);
  x_dot(2,1) = ( ( const.B_44*X(2) )...
    - ( const.C_44*X(1)*( const.GM_m+const.GM_a*X(5) ) )...
    + ( const.K_phi3*(X(1)^3) ) ) / const.Ix_A44;
  x_dot(3,1) = ( U-(const.B_11*(abs(X(3)))*X(3)) )/const.m_A11;
  x_dot(4,1) = 0;
  x_dot(5,1) = X(6);
  x_dot(6,1) = ( -X(5)*(( X(4)+(X(3)*(X(4)^2)/const.g) )^2) )...
    + ( (X(4)*X(6)/(X(3)*X(4)+const.g))*x_dot(3,1) );
  x_dot(7,1) = X(8);
  x_dot(8,1) = - (const.omega_0^2)*X(7)...
    - ( 2*const.lambda*const.omega_0*X(8) )...
    + ( const.K_w*BoxMuller(0.1,const.K_w) );
end