function [ x_dot ] = f_wave_dir( X,U,const )
% F_WAVE_DIR returns the f = x_dot for a container vessel 
%  during parametric resonance, for a given time instant.
%
% [ x_dot ] = f_wave_dir( X,U,const )
%         X - system state [X(1) X(2) ... X(8) X(9)]' 
            % X(1) = phi
            % X(2) = (phi_dot)
            % X(3) = u
            % X(4) = w_0
            % X(5) = cos(integral[w_e(t)dt])
            % X(6) = d/dt cos(integral[w_e(t)dt])
            % X(7) = h_{wave}(s) 
            % X(8) = h_{wave}(s)_dot
            % X(9) = beta
%         U - system input vector
%     DELTA - rudder angle
%     const - a struct with constant values 

  x_dot(1,1) = X(2);
  x_dot(2,1) = ( ( const.B_44*X(2) )...
    - ( const.C_44*X(1)*( const.GM_m+const.GM_a*X(5) ) )...
    + ( const.K_phi3*(X(1)^3) ) ) / const.Ix_A44;
  x_dot(3,1) = ( U(1)-(const.B_11*(abs(X(3)))*X(3)) )/const.m_A11;
  x_dot(4,1) = 0;
  x_dot(5,1) = X(6);
  x_dot(6,1) = ( -X(5)*...
      ( (X(4)+((X(3)*(X(4)^2)*cos(X(9)-U(2)))/const.g))^2) )...
    - ( (X(4)*X(6)/(const.g - X(3)*X(4) *cos(X(9)-U(2))) )*...
       x_dot(3,1)*cos( X(9)-U(2) ) )...
    - ( (cos(X(1))*X(3)*X(4)*X(6)*U(3)...
       / (const.g - X(3)*X(4) *cos( X(9)-U(2) )) )*...
       sin(X(9)-U(3)) );
  x_dot(7,1) = X(8);
  x_dot(8,1) = - (const.omega_0^2)*X(7)...
    - ( 2*const.lambda*const.omega_0*X(8) )...
    + ( const.K_w*BoxMuller(0.1,const.K_w) );
  x_dot(9,1) = 0;
end