% INIT 
%  returns the parameters for the container vessel,
%  in base SI units (kg-m-s).

clear all; close all; clc;

% Conversion
D2R = pi/180;  % deg to rad
R2D = 180/pi;  % rad to deg

% Ship Model Parameters
const.I_x = 1.4014*(10^10);%Rigid-body inertia (in roll)
const.A_44 = 2.17*(10^9);%Added mass
const.Ix_A44 = const.I_x + const.A_44; 
const.B_44 = -3.20*(10^8);%Linear damping coefficient
const.GM_m = 1.91; %MCH
const.GM_a = 0.84; %Amplitude of MCH change
const.omega_0 = 0.4684; %Resonance frequency
const.K_phi3 = -2.974*(10^9);%Restoring force
const.lambda = 0.1018;%Relative damping factor
const.sigma = 1.2871;%Sigma gain
const.K_w = 2*const.lambda*const.omega_0*const.sigma;%Gain h_w(s)
const.m = 7.6654*(10^7);%Mass of the ship
const.A_11 = 7.746*(10^6);%Added mass
const.m_A11 = const.m + const.A_11;
const.L_pp = 281;  %Ship length between perpendiculars
const.v = 1.519*(10^-6);%Kinematic viscosity
const.u = 7;       %Ship speed
const.R_n = const.u*const.L_pp/const.v; %Reynolds number
const.rho = 1025;  %Water density
const.S = 6600;    %Wetted surface
const.k = 0.1;     %Factor
const.B_11 = 0.5*const.rho*const.S... %Hydrodynamic resistance
             *(1+const.k)*0.075...
             /(((log(const.R_n)/log(10))-2)^2);      
const.g = 9.81;    %Gravitational acceleration
const.nabla = 76468;%Displaced water volume
const.C_44 = const.rho*const.g*const.nabla;%Restoring moment factor
const.k_p = -1e1;  %Feedback linearization controller gain             
const.w_0 = 0.4764;%Modal wave frequency
const.u_c = 7;     %Control speed
u0 = 7.5;          %Initial speed

% Initial states
x_init = [0.1*D2R,0,u0,const.w_0,1,0,0,0]'; 
x_init_wave_dir = [0.1*D2R,0,u0,const.w_0,1,0,0,0,pi]';

% Constants for the Nomoto model (mariner class cargo ship)
const.T1 = 118;  const.T2 = 7.8; %Time constants
const.T3 = 18.5; const.T  = const.T1+const.T2-const.T3;
const.K  = 0.185;   %Static yaw rate gain

% Rudder Angle Controller Parameters
const.lambda_1 = 15000; 
const.lambda_2 = 8.0;  %Weighting factor
const.K_p = sqrt(1/const.lambda_2);  %Proportional gain
const.K_d = (const.L_pp/const.u)*... %Derivative gain
   ((sqrt(1 + 2*const.K_p*const.K*const.T ...
   + const.K^2*(const.u/const.L_pp)^2 ...
   *(const.lambda_1/const.lambda_2))-1)/const.K);
const.psi_d = 10*D2R;   %Desired heading (deg)