function xnext = rk4( f,x,u,h )
% RK4 Integrate a system of ordinary differential 
%  equations using Runge-Kutta's 4th-order method. 
%
% The output xnext = rk4( 'f',x,u,h )
%  f - external function: dx/dt(k) = f(x(k),u(k))
%  x - x(k)
%  u - ext. function: u(k) (const. over sample time h)
%  h - step size
%
% Copyright (C) 2008 Thor I. Fossen and Tristan Perez

 xo = x;
    k1 = h*feval(f,xo,u);
    x  = xo+0.5*k1;
    k2 = h*feval(f,x,u);
    x  = xo+0.5*k2;
    k3 = h*feval(f,x,u);
    x  = xo+k3;
    k4 = h*feval(f,x,u);
 xnext = xo + (k1+2*(k2+k3)+k4)/6;
end