function [ Wm,Wc,c ] = ut_weights( L,alpha,kappa,beta )
% UT_WEIGHTS computes unscented transformation weights.
%  The function returns: 
%    weights for mean calculation, Wm, 
%    weights for covariance calculation, Wc, 
%    and a scaling constant, c.
%
% [ Wm,Wc,c ] = ut_weights( L,alpha,kappa,beta )
%           L - number of states
%       alpha - transformation parameter
%       kappa - transformation parameter
%        beta - transformation parameter

 lambda = (( alpha^2 )*( L+kappa )) - L;                   
 c =  L + lambda;                      
 Wm = [lambda/c (0.5/c)+zeros(1,2*L)]; 
 Wc = Wm;                              
 Wc(1,1) = Wc(1,1) + (1 - (alpha^2) + beta);     
end